#if defined _items_core_included
    #endinput
#endif
#define _items_core_included

/*
**
**    ______                 __              __      
**   / ____/___  ____  _____/ /_____ _____  / /______
**  / /   / __ \/ __ \/ ___/ __/ __ `/ __ \/ __/ ___/
** / /___/ /_/ / / / (__  ) /_/ /_/ / / / / /_(__  ) 
** \____/\____/_/ /_/____/\__/\__,_/_/ /_/\__/____/  
**                                                   
**
*/

// ---- Flags and everything -------------------------------------------------------
#define MAX_SLOTS                  8

#define FLAG_HIDE_SCOUT_HAT        (1 << 0)
#define FLAG_HIDE_SCOUT_HEADPHONES (1 << 1)
#define FLAG_HIDE_HEAVY_HANDS      (1 << 2)
#define FLAG_HIDE_ENGINEER_HELMET  (1 << 3)
#define FLAG_SHOW_SNIPER_QUIVER    (1 << 4)
#define FLAG_HIDE_SNIPER_HAT       (1 << 5)
#define FLAG_HIDE_SOLDIER_ROCKET   (1 << 6)
#define FLAG_HIDE_SOLDIER_HELMET   (1 << 7)
#define FLAG_SHOW_SOLDIER_MEDAL    (1 << 8)

#define BODYGROUP_SCOUT_HAT        (1 << 0)
#define BODYGROUP_SCOUT_HEADPHONES (1 << 1)
#define BODYGROUP_HEAVY_HANDS      (1 << 0)
#define BODYGROUP_ENGINEER_HELMET  (1 << 0)
#define BODYGROUP_SNIPER_QUIVER    (1 << 0)
#define BODYGROUP_SNIPER_HAT       (1 << 1)
#define BODYGROUP_SOLDIER_ROCKET   (1 << 0)
#define BODYGROUP_SOLDIER_HELMET   (1 << 1)
#define BODYGROUP_SOLDIER_MEDAL    (1 << 2)

// ---- Plugin constants -----------------------------------------------------------
enum eItemCodes
{
   Success                  = 1,
   Error_InvalidItem        = -1,
   Error_NotInit            = -2,
   Error_AlreadyExists      = -3,
   Error_NotFound           = -4,
   Error_Cancelled          = -5,
   Error_CanNotUse          = -6,
   Error_InvalidClient      = -7,
   Error_InvalidSlot        = -8
};

/*
**
**     ______                                   __    
**    / ____/___  ______      ______ __________/ /____
**   / /_  / __ \/ ___/ | /| / / __ `/ ___/ __  / ___/
**  / __/ / /_/ / /   | |/ |/ / /_/ / /  / /_/ (__  ) 
** /_/    \____/_/    |__/|__/\__,_/_/   \__,_/____/  
**                                                    
**
*/

/* OnItemCreated()
**
** Called whenever an item has been created and registered in the plugin.
** -------------------------------------------------------------------------- */
forward OnItemCreated(Handle:hItem);

/* OnItemDeleted()
**
** Called whenever an item has been deleted.
** -------------------------------------------------------------------------- */
forward OnItemDeleted(Handle:hItem);

/* CanPlayerUseItem()
**
** Determines if the given item can be used by the client. The reference va-
** riable "bCanUse" tells the plugin if it's permitted to use it or not. The
** "iTopLevel" one is an optional variable in case you want to stablish an
** hierarchy between plugins when deciding if it's usable.
**
** For example, if plugin A with level 4 says the item is usable, but the
** plugin B with level 10 says it isn't, if both plugins respect the hierachical
** levels, the plugin B will be the one to decide if it's useable.
** -------------------------------------------------------------------------- */
forward CanPlayerUseItem(iClient, Handle:hItem, &bool:bCanUse, &iTopLevel);

/* OnPlayerEquipItem()
**
** Called whenever a client successfully equipped an item.
** -------------------------------------------------------------------------- */
forward OnPlayerEquipItem(iClient, Handle:hItem, bool:bRegenerating);

/* OnPlayerEquipItemPre()
**
** Called whenever a client is about to equip an item. This call is always done
** before the CanPlayerUseItem forward, and returning the action Plugin_Stop will
** inmediately cancel the equip method.
** -------------------------------------------------------------------------- */
forward Action:OnPlayerEquipItemPre(iClient, Handle:hItem, bool:bRegenerating);

/* OnPlayerRemoveItem()
**
** Called whenever a client successfully removed an item.
** -------------------------------------------------------------------------- */
forward OnPlayerRemoveItem(iClient, Handle:hItem, bool:bDeleted);

/* OnPlayerRemoveItemPre()
**
** Called whenever a client is about to remove an item. Returning the action
** state Plugin_Stop will inmediately cancel the remove method.
** -------------------------------------------------------------------------- */
forward Action:OnPlayerRemoveItemPre(iClient, Handle:hItem, bool:bDeleted);

/* OnItemPreload()
**
** Tells the other plugins we're about to preload.
** -------------------------------------------------------------------------- */
forward OnItemPreload();

/*
**
**     _   __      __  _                
**    / | / /___ _/ /_(_)   _____  _____
**   /  |/ / __ `/ __/ / | / / _ \/ ___/
**  / /|  / /_/ / /_/ /| |/ /  __(__  ) 
** /_/ |_/\__,_/\__/_/ |___/\___/____/  
**                                      
**                                                   
**
*/

/* CreateItem()
**
** Fake native method wich obtains an item structure and registers it onto the
** plugin tables.
** -------------------------------------------------------------------------- */
native eItemCodes:CreateItem(Handle:hItem);

/* DeleteItem()
**
** Deletes the given item from the tables and removes it from any player that 
** had it equipped.
** -------------------------------------------------------------------------- */
native eItemCodes:DeleteItem(Handle:hItem);

/* FindItemByName()
**
** Looksup the tables to find the given item through it's short name.
** -------------------------------------------------------------------------- */
native Handle:FindItemByName(String:strName[]);

/* CountItems()
**
** Returns the item count.
** -------------------------------------------------------------------------- */
native CountItems();

/* GetItemFromTable()
**
** Navigates and returns an item from the table.
** -------------------------------------------------------------------------- */
native Handle:GetItemFromTable(iIndex);

/* CountItemSlots()
**
** Retrieves the number of slots available for the items.
** -------------------------------------------------------------------------- */
native CountItemSlots();

/* GetItemAtSlot()
**
** Retrieves the equipped item at the given slot.
** -------------------------------------------------------------------------- */
native Handle:GetItemAtSlot(iClient, iSlot);

/* SetItemAtSlot()
**
** Sets the equipped item at the given slot.
** -------------------------------------------------------------------------- */
native Handle:SetItemAtSlot(iClient, iSlot, Handle:hItem);


/* QueryPlayerCanUseItem()
**
** Queries the other plugins to check if the given item can be used by the
** client.
** -------------------------------------------------------------------------- */
native bool:QueryPlayerCanUseItem(iClient, Handle:hItem);

/* EquipPlayerItem()
**
** Equips the given item on the player, querying the other plugins for it.
** -------------------------------------------------------------------------- */
native eItemCodes:EquipPlayerWearableItem(iClient, Handle:hItem);

/* RemovePlayerItem()
**
** Removes the given item on the player (if it's equipped)
** -------------------------------------------------------------------------- */
native eItemCodes:RemovePlayerWearableItem(iClient, Handle:hItem);

/* RemovePlayerItemSlot()
**
** Removes the item equipped on the slot (if any)
** -------------------------------------------------------------------------- */
native eItemCodes:RemoveWearableItemSlot(iClient, iSlot);

/*
** 
**      __  ___            _             __      __  _           
**     /  |/  /___ _____  (_)___  __  __/ /___ _/ /_(_)___  ____ 
**    / /|_/ / __ `/ __ \/ / __ \/ / / / / __ `/ __/ / __ \/ __ \
**   / /  / / /_/ / / / / / /_/ / /_/ / / /_/ / /_/ / /_/ / / / /
**  /_/  /_/\__,_/_/ /_/_/ .___/\__,_/_/\__,_/\__/_/\____/_/ /_/ 
**                      /_/                                       
** 
** 
*/

/* SetItem...()
**
** Methods to change the basic properties of the item structures.
** -------------------------------------------------------------------------- */
stock SetItemName(Handle:hItem, String:strBuffer[])     { SetTrieString(hItem, "name",       strBuffer);   }
stock SetItemLongName(Handle:hItem, String:strBuffer[]) { SetTrieString(hItem, "long-name",  strBuffer);   }
stock SetItemModel(Handle:hItem, String:strBuffer[])    { SetTrieString(hItem, "model",      strBuffer);   }
stock SetItemIndex(Handle:hItem, iIndex)                { SetTrieValue(hItem,  "index",      iIndex);      }
stock SetItemQuality(Handle:hItem, iQuality)            { SetTrieValue(hItem,  "quality",    iQuality);    }
stock SetItemLevel(Handle:hItem, iLevel)                { SetTrieValue(hItem,  "level",      iLevel);      }
stock SetItemSlot(Handle:hItem, iSlot)                  { SetTrieValue(hItem,  "slot",       iSlot);       }
stock SetItemBodyGroups(Handle:hItem, iBodyGroups)      { SetTrieValue(hItem,  "bodygroups", iBodyGroups); }

/* GetItem...()
**
** Methods to retrieve the basic properties of the item structures.
** -------------------------------------------------------------------------- */
stock GetItemName(Handle:hItem, String:strBuffer[], iMaxLength)     { GetTrieString(hItem, "name",      strBuffer, iMaxLength); }
stock GetItemLongName(Handle:hItem, String:strBuffer[], iMaxLength) { GetTrieString(hItem, "long-name", strBuffer, iMaxLength); }
stock GetItemModel(Handle:hItem, String:strBuffer[], iMaxLength)    { GetTrieString(hItem, "model",     strBuffer, iMaxLength); }
stock GetItemIndex(Handle:hItem)                                    { decl iValue; GetTrieValue(hItem, "index",      iValue); return iValue; }
stock GetItemQuality(Handle:hItem)                                  { decl iValue; GetTrieValue(hItem, "quality",    iValue); return iValue; }
stock GetItemLevel(Handle:hItem)                                    { decl iValue; GetTrieValue(hItem, "level",      iValue); return iValue; }
stock GetItemSlot(Handle:hItem)                                     { decl iValue; GetTrieValue(hItem, "slot",       iValue); return iValue; }
stock GetItemBodyGroups(Handle:hItem)                               { decl iValue; GetTrieValue(hItem, "bodygroups", iValue); return iValue; }

/*
**
**     ____                            __                _          
**    / __ \___  ____  ___  ____  ____/ /__  ____  _____(_)__  _____
**   / / / / _ \/ __ \/ _ \/ __ \/ __  / _ \/ __ \/ ___/ / _ \/ ___/
**  / /_/ /  __/ /_/ /  __/ / / / /_/ /  __/ / / / /__/ /  __(__  ) 
** /_____/\___/ .___/\___/_/ /_/\__,_/\___/_/ /_/\___/_/\___/____/  
**           /_/                                                    
**                                                   
**
*/
public SharedPlugin:__pl_ItemsCore = 
{
    name = "ItemsCore",
    file = "TF2_ItemsCore.smx",
#if defined REQUIRE_PLUGIN
    required = 1,
#else
    required = 0,
#endif
};

public __pl_ItemsCore_SetNTVOptional()
{
}